@@ -153,8 +153,9 @@ class CorrTransformer( BaseEstimator, TransformerMixin ):
         new_df = X.drop(self.to_drop,axis=1,inplace=False)  
         return new_df
         
+     
+       
     
- 
 class CatTransformer( BaseEstimator, TransformerMixin ):
     #Class Constructor 
     def __init__( self, pp  = "le" , console= False ):
@@ -196,15 +197,22 @@ class CatTransformer( BaseEstimator, TransformerMixin ):
         #print(self.cat_encoders)
         for name, encs in self.cat_encoders :
             df_c = encs.transform(X[name])
-            prefix = str(name) + "_"
             
+            prefix = str(name) + "_"
+
             if(self.pp=="le"):
                 self.encoded_df.append(pd.DataFrame(df_c,columns=[name],index=X.index))
             elif(self.pp=="lb"):
-                if(df_c.shape[1]==1):
-                    self.encoded_df.append(pd.DataFrame(df_c,columns=[name],index=X.index))
+                #self.encoded_df.append(pd.DataFrame(df_c,columns=encs.classes_,index=X.index).add_prefix(str(prefix).upper()))
+                if(df_c.shape[1]==1):                    
+                    if (len(encs.classes_)==2):  
+                        classe_1 = encs.classes_[1]+"_pos_"+encs.classes_[0]+"_neg"
+                        self.encoded_df.append(pd.DataFrame(df_c,columns=[classe_1],index=X.index).add_prefix(str(prefix).upper()))
+                    else:
+                        self.encoded_df.append(pd.DataFrame(df_c,columns=[name],index=X.index))                    
                 else:                
                     self.encoded_df.append(pd.DataFrame(df_c,columns=encs.classes_,index=X.index).add_prefix(str(prefix).upper()))          
+            
             else:
                 print("Error: pp INVALIDO")
                 break;            
@@ -227,7 +235,6 @@ class CatTransformer( BaseEstimator, TransformerMixin ):
         #print(list(y.columns))
         return new_df
         
-        
      
         
         
